@@ -29,7 +29,7 @@
 #
 ###############################################################################
 #
-# $Id: fwcheck_psad.pl 2026 2007-03-27 01:42:04Z mbr $
+# $Id: fwcheck_psad.pl 2243 2008-08-31 13:46:47Z mbr $
 #
 
 use Getopt::Long 'GetOptions';
@@ -389,7 +389,8 @@ sub get_psad_mod_paths() {
         ### get directories like "/usr/lib/psad/x86_64-linux"
         next unless -d "$config{'PSAD_LIBS_DIR'}/$dir";
         push @paths, "$config{'PSAD_LIBS_DIR'}/$dir"
-            if $dir =~ m|linux| or $dir =~ m|thread|;
+            if $dir =~ m|linux| or $dir =~ m|thread|
+                or (-d "$config{'PSAD_LIBS_DIR'}/$dir/auto");
     }
     return \@paths;
 }
@@ -493,7 +494,13 @@ sub check_commands() {
         ### if "nomail" is set in REPORT_METHOD, and sendmail is only
         ### required if DShield alerting is enabled and a DShield user
         ### email is set.
-        next if $cmd =~ /mail/i;
+        if ($cmd eq 'mail') {
+            next CMD if $config{'ALERTING_METHODS'} =~ /no.?e?mail/i;
+        } elsif ($cmd eq 'sendmail') {
+            next CMD unless ($config{'ENABLE_DSHIELD_ALERTS'} eq 'Y'
+                and $config{'DSHIELD_ALERT_EMAIL'} ne 'NONE');
+        }
+
         next if $cmd eq 'wget';  ### only used in --sig-update mode
         unless (-x $cmds{$cmd}) {
             my $found = 0;
